@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # maxCPU
-# Version 0.1.8-3 English version
+# Version 0.1.8-x English version
 # Home Desktop Widget for quickly changin of CPU's clock
 # by Marco (m750 at www.maemomeego.net)
 
@@ -255,8 +255,8 @@ class maxCPU(hildondesktop.HomePluginItem):
         # dialog crea una finestra in basso con dei messaggi
         dialog = gtk.Dialog()
         dialog.set_title('maxCPU')
-        dialog.vbox.add(gtk.Label("Quickly changin of CPU's clock"))
-        dialog.vbox.add(gtk.Label('Version 0.1.8 EN (2011-02-13)'))
+        dialog.vbox.add(gtk.Label("Quickly changing of CPU's clock"))
+        dialog.vbox.add(gtk.Label('Version 0.1.8-X EN (2011-02-13)'))
         dialog.vbox.add(gtk.Label('250 Mhz<= Fmin <= newClock <= 1150 Mhz'))
         dialog.vbox.add(gtk.Label('Changes do not remain after reboot'))
         dialog.vbox.add(gtk.Label('Work only with Power Kernel, packages:'))
